@@ -56,8 +56,10 @@
 #endif
 
 #include <libxml/xmlmemory.h>
-#include <libxml/nanoftp.h>
+#include <libxml/parser.h>
 #include <libxml/xmlerror.h>
+#include <libxml/nanoftp.h>
+#include <libxml/globals.h>
 
 /* #define DEBUG_FTP 1  */
 #ifdef STANDALONE
@@ -73,8 +75,9 @@
 #define closesocket(s) close(s)
 #define SOCKET int
 #endif
-
-static char hostname[100];
+#if defined(VMS) || defined(__VMS)
+#define SOCKLEN_T unsigned int
+#endif
 
 #define FTP_COMMAND_OK		200
 #define FTP_SYNTAX_ERROR	500
@@ -131,8 +134,6 @@ xmlNanoFTPInit(void) {
 	return;
 #endif
 
-    gethostname(hostname, sizeof(hostname));
-
     proxyPort = 21;
     env = getenv("no_proxy");
     if (env != NULL)
@@ -177,7 +178,6 @@ xmlNanoFTPCleanup(void) {
 	xmlFree(proxyPasswd);
 	proxyPasswd = NULL;
     }
-    hostname[0] = 0;
 #ifdef _WINSOCKAPI_
     if (initialized)
 	WSACleanup();
@@ -759,7 +759,7 @@ xmlNanoFTPSendUser(void *ctx) {
     buf[sizeof(buf) - 1] = 0;
     len = strlen(buf);
 #ifdef DEBUG_FTP
-    xmlGenericError(xmlGenericErrorContext, buf);
+    xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
     res = send(ctxt->controlFd, buf, len, 0);
     if (res < 0) return(res);
@@ -778,13 +778,13 @@ xmlNanoFTPSendPasswd(void *ctx) {
     int res;
 
     if (ctxt->passwd == NULL)
-	snprintf(buf, sizeof(buf), "PASS libxml@%s\r\n", hostname);
+	snprintf(buf, sizeof(buf), "PASS anonymous@\r\n");
     else
 	snprintf(buf, sizeof(buf), "PASS %s\r\n", ctxt->passwd);
     buf[sizeof(buf) - 1] = 0;
     len = strlen(buf);
 #ifdef DEBUG_FTP
-    xmlGenericError(xmlGenericErrorContext, buf);
+    xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
     res = send(ctxt->controlFd, buf, len, 0);
     if (res < 0) return(res);
@@ -811,7 +811,7 @@ xmlNanoFTPQuit(void *ctx) {
     sprintf(buf, "QUIT\r\n");
     len = strlen(buf);
 #ifdef DEBUG_FTP
-    xmlGenericError(xmlGenericErrorContext, buf);
+    xmlGenericError(xmlGenericErrorContext, "%s", buf); /* Just to be consistent, even though we know it can't have a % in it */
 #endif
     res = send(ctxt->controlFd, buf, len, 0);
     return(0);
@@ -933,7 +933,7 @@ xmlNanoFTPConnect(void *ctx) {
             buf[sizeof(buf) - 1] = 0;
             len = strlen(buf);
 #ifdef DEBUG_FTP
-	    xmlGenericError(xmlGenericErrorContext, buf);
+	    xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
 	    res = send(ctxt->controlFd, buf, len, 0);
 	    if (res < 0) {
@@ -950,12 +950,11 @@ xmlNanoFTPConnect(void *ctx) {
 		    if (proxyPasswd != NULL)
 			snprintf(buf, sizeof(buf), "PASS %s\r\n", proxyPasswd);
 		    else
-			snprintf(buf, sizeof(buf), "PASS libxml@%s\r\n",
-			               hostname);
+			snprintf(buf, sizeof(buf), "PASS anonymous@\r\n");
                     buf[sizeof(buf) - 1] = 0;
                     len = strlen(buf);
 #ifdef DEBUG_FTP
-		    xmlGenericError(xmlGenericErrorContext, buf);
+		    xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
 		    res = send(ctxt->controlFd, buf, len, 0);
 		    if (res < 0) {
@@ -995,7 +994,7 @@ xmlNanoFTPConnect(void *ctx) {
                 buf[sizeof(buf) - 1] = 0;
                 len = strlen(buf);
 #ifdef DEBUG_FTP
-		xmlGenericError(xmlGenericErrorContext, buf);
+		xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
 		res = send(ctxt->controlFd, buf, len, 0);
 		if (res < 0) {
@@ -1025,7 +1024,7 @@ xmlNanoFTPConnect(void *ctx) {
                 buf[sizeof(buf) - 1] = 0;
                 len = strlen(buf);
 #ifdef DEBUG_FTP
-		xmlGenericError(xmlGenericErrorContext, buf);
+		xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
 		res = send(ctxt->controlFd, buf, len, 0);
 		if (res < 0) {
@@ -1040,13 +1039,13 @@ xmlNanoFTPConnect(void *ctx) {
 		    return(0);
 		}    
 		if (ctxt->passwd == NULL)
-		    snprintf(buf, sizeof(buf), "PASS libxml@%s\r\n", hostname);
+		    snprintf(buf, sizeof(buf), "PASS anonymous@\r\n");
 		else
 		    snprintf(buf, sizeof(buf), "PASS %s\r\n", ctxt->passwd);
                 buf[sizeof(buf) - 1] = 0;
                 len = strlen(buf);
 #ifdef DEBUG_FTP
-		xmlGenericError(xmlGenericErrorContext, buf);
+		xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
 		res = send(ctxt->controlFd, buf, len, 0);
 		if (res < 0) {
@@ -1184,7 +1183,7 @@ xmlNanoFTPCwd(void *ctx, char *directory) {
     buf[sizeof(buf) - 1] = 0;
     len = strlen(buf);
 #ifdef DEBUG_FTP
-    xmlGenericError(xmlGenericErrorContext, buf);
+    xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
     res = send(ctxt->controlFd, buf, len, 0);
     if (res < 0) return(res);
@@ -1234,7 +1233,7 @@ xmlNanoFTPGetConnection(void *ctx) {
 	sprintf(buf, "PASV\r\n");
         len = strlen(buf);
 #ifdef DEBUG_FTP
-	xmlGenericError(xmlGenericErrorContext, buf);
+	xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
 	res = send(ctxt->controlFd, buf, len, 0);
 	if (res < 0) {
@@ -1300,7 +1299,7 @@ xmlNanoFTPGetConnection(void *ctx) {
         buf[sizeof(buf) - 1] = 0;
         len = strlen(buf);
 #ifdef DEBUG_FTP
-	xmlGenericError(xmlGenericErrorContext, buf);
+	xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
 
 	res = send(ctxt->controlFd, buf, len, 0);
@@ -1534,7 +1533,7 @@ xmlNanoFTPList(void *ctx, ftpListCallback callback, void *userData,
     buf[sizeof(buf) - 1] = 0;
     len = strlen(buf);
 #ifdef DEBUG_FTP
-    xmlGenericError(xmlGenericErrorContext, buf);
+    xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
     res = send(ctxt->controlFd, buf, len, 0);
     if (res < 0) {
@@ -1628,7 +1627,7 @@ xmlNanoFTPGetSocket(void *ctx, const char *filename) {
     sprintf(buf, "TYPE I\r\n");
     len = strlen(buf);
 #ifdef DEBUG_FTP
-    xmlGenericError(xmlGenericErrorContext, buf);
+    xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
     res = send(ctxt->controlFd, buf, len, 0);
     if (res < 0) {
@@ -1647,7 +1646,7 @@ xmlNanoFTPGetSocket(void *ctx, const char *filename) {
     buf[sizeof(buf) - 1] = 0;
     len = strlen(buf);
 #ifdef DEBUG_FTP
-    xmlGenericError(xmlGenericErrorContext, buf);
+    xmlGenericError(xmlGenericErrorContext, "%s", buf);
 #endif
     res = send(ctxt->controlFd, buf, len, 0);
     if (res < 0) {
